@@ -1,6 +1,6 @@
-#!/usr/bin/env python
-from __future__ import absolute_import
-"""Convienance entry point for cwltool.
+#!/usr/bin/env python3
+# PYTHON_ARGCOMPLETE_OK
+"""Convenience entry point for cwltool.
 
 This can be used instead of the recommended method of `./setup.py install`
 or `./setup.py develop` and then using the generated `cwltool` executable.
@@ -11,4 +11,4 @@ import sys
 from cwltool import main
 
 if __name__ == "__main__":
-    sys.exit(main.main(sys.argv[1:]))
+    main.run(sys.argv[1:])
