@@ -11,6 +11,7 @@ from .loghandler import _logger
 
 
 def resolve_local(document_loader: Optional[Loader], uri: str) -> Optional[str]:
+    """Use the local resolver to find the target of the URI."""
     pathpart, frag = urllib.parse.urldefrag(uri)
 
     try:
@@ -41,6 +42,7 @@ def resolve_local(document_loader: Optional[Loader], uri: str) -> Optional[str]:
 
 
 def tool_resolver(document_loader: Loader, uri: str) -> Optional[str]:
+    """Try both the local resolver and the GA4GH TRS resolver, in that order."""
     for r in [resolve_local, resolve_ga4gh_tool]:
         ret = r(document_loader, uri)
         if ret is not None:
@@ -63,6 +65,7 @@ GA4GH_TRS_PRIMARY_DESCRIPTOR = "{0}/api/ga4gh/v2/tools/{1}/versions/{2}/plain-CW
 
 
 def resolve_ga4gh_tool(document_loader: Loader, uri: str) -> Optional[str]:
+    """Use the GA4GH TRS API to resolve a tool reference."""
     path, version = uri.partition(":")[::2]
     if not version:
         version = "latest"
