@@ -1,5 +1,6 @@
 """ProcessGenerator related tests."""
 
+from pathlib import Path
 
 import pytest
 
@@ -8,14 +9,25 @@ from cwltool.main import main
 from .util import get_data
 
 
-def test_missing_enable_ext(monkeypatch: pytest.MonkeyPatch) -> None:
+def test_missing_enable_ext(monkeypatch: pytest.MonkeyPatch, tmp_path: Path) -> None:
     """Test missing enable-ext option fails.
 
     Check that a workflow that needs `--enable-ext` and
     `--enable-dev` fails without those options and passes with them.
     """
     monkeypatch.delenv("CWLTOOL_OPTIONS", raising=False)
-    assert main([get_data("tests/wf/generator/zing.cwl"), "--zing", "zipper"]) == 1
+    assert (
+        main(
+            [
+                "--outdir",
+                str(tmp_path),
+                get_data("tests/wf/generator/zing.cwl"),
+                "--zing",
+                "zipper",
+            ]
+        )
+        == 1
+    )
 
     assert (
         main(
@@ -23,6 +35,8 @@ def test_missing_enable_ext(monkeypatch: pytest.MonkeyPatch) -> None:
                 "--debug",
                 "--enable-ext",
                 "--enable-dev",
+                "--outdir",
+                str(tmp_path),
                 get_data("tests/wf/generator/zing.cwl"),
                 "--zing",
                 "zipper",
@@ -32,4 +46,15 @@ def test_missing_enable_ext(monkeypatch: pytest.MonkeyPatch) -> None:
     )
 
     monkeypatch.setenv("CWLTOOL_OPTIONS", "--enable-ext --enable-dev")
-    assert main([get_data("tests/wf/generator/zing.cwl"), "--zing", "zipper"]) == 0
+    assert (
+        main(
+            [
+                "--outdir",
+                str(tmp_path),
+                get_data("tests/wf/generator/zing.cwl"),
+                "--zing",
+                "zipper",
+            ]
+        )
+        == 0
+    )
