@@ -13,11 +13,13 @@ from schema_salad.avro import schema
 from cwltool.builder import Builder
 from cwltool.command_line_tool import CommandLineTool, ExpressionTool
 from cwltool.context import LoadingContext, RuntimeContext
+from cwltool.procgenerator import ProcessGenerator
 from cwltool.stdfsaccess import StdFsAccess
 from cwltool.update import INTERNAL_VERSION
 from cwltool.workflow import Workflow
 
 from .test_anon_types import snippet
+from .util import get_data
 
 
 @pytest.mark.parametrize("snippet", snippet)
@@ -52,6 +54,35 @@ def test_pickle_unpickle_workflow(snippet: CommentedMap) -> None:
     assert pickle.loads(stream)
 
 
+def test_pickle_processgenerator() -> None:
+    """We can pickle ProcessGenerator."""
+
+    pytoolgen = get_data("tests/wf/generator/pytoolgen.cwl")
+    a = ProcessGenerator(
+        CommentedMap(
+            {
+                "cwlVersion": "v1.0",
+                "id": f"file://{pytoolgen}",
+                "$namespaces": {"cwltool": "http://commonwl.org/cwltool#"},
+                "class": "cwltool:ProcessGenerator",
+                "inputs": {},
+                "outputs": {},
+                "run": {
+                    "id": f"file://{pytoolgen}#f9f617af-3088-4ade-bbf3-acd1d6f51355",
+                    "cwlVersion": "v1.0",
+                    "class": "CommandLineTool",
+                    "inputs": {},
+                    "outputs": {},
+                    "baseCommand": "echo",
+                },
+            },
+        ),
+        LoadingContext(),
+    )
+
+    assert pickle.dumps(a)
+
+
 def test_serialize_builder() -> None:
     """We can pickle Builder."""
     runtime_context = RuntimeContext()
